@@ -1,10 +1,13 @@
-import pkg_resources
+import logging
+
 import numpy as np
+import pkg_resources
+
 from dkist_processing_pac import Data
 from dkist_processing_pac.tag import tag
 
 
-class CalibrationSequence():
+class CalibrationSequence:
     """Set up the Mueller matrices of the Calibration Unit at each step in a Calibration Sequence. The sequence is
     defined by vectors containing the angles of the polarizer and retarder, but each of these elements can either be
     inserted or removed from the beam as necessary.
@@ -30,12 +33,28 @@ class CalibrationSequence():
 
     """
 
-    def __init__(self, theta_pol_steps, theta_ret_steps, pol_in, ret_in, dark_in, timeobs,
-                 ret_0_h=0., dret_h=0.,
-                 ret_0_45=0., dret_45=0.,
-                 ret_0_r=0., dret_r=0.,
-                 t_pol_0=1., t_ret_0=1., py=0,
-                 I_sys = 1., Q_in=0, U_in=0, V_in=0):
+    def __init__(
+        self,
+        theta_pol_steps,
+        theta_ret_steps,
+        pol_in,
+        ret_in,
+        dark_in,
+        timeobs,
+        ret_0_h=0.0,
+        dret_h=0.0,
+        ret_0_45=0.0,
+        dret_45=0.0,
+        ret_0_r=0.0,
+        dret_r=0.0,
+        t_pol_0=1.0,
+        t_ret_0=1.0,
+        py=0,
+        I_sys=1.0,
+        Q_in=0,
+        U_in=0,
+        V_in=0,
+    ):
         """Initialize the Calibration Unit at each of the polarizer/retarder angles provided in the Calibration Sequence
 
         The values for the properties of the optical elements and the angular uncertainty can also be provided.
@@ -68,11 +87,13 @@ class CalibrationSequence():
         py : float
             Transmission coefficient of the E_y electric field through the polarizer
         """
-        if theta_ret_steps.shape != theta_pol_steps.shape or \
-                theta_ret_steps.shape != pol_in.shape or \
-                theta_ret_steps.shape != ret_in.shape or \
-                theta_ret_steps.shape != timeobs.shape:
-            raise ValueError('Calibration Sequence step arrays do not have the same shape')
+        if (
+            theta_ret_steps.shape != theta_pol_steps.shape
+            or theta_ret_steps.shape != pol_in.shape
+            or theta_ret_steps.shape != ret_in.shape
+            or theta_ret_steps.shape != timeobs.shape
+        ):
+            raise ValueError("Calibration Sequence step arrays do not have the same shape")
 
         self.theta_pol_steps = theta_pol_steps * np.pi / 180
         self.theta_ret_steps = theta_ret_steps * np.pi / 180
@@ -117,12 +138,14 @@ class CalibrationSequence():
             A new CalibrationSequence object
         """
 
-        output = CalibrationSequence(np.append(self.theta_pol_steps, other.theta_pol_steps) * 180 / np.pi,
-                                     np.append(self.theta_ret_steps, other.theta_ret_steps) * 180 / np.pi,
-                                     np.append(self.pol_in, other.pol_in),
-                                     np.append(self.ret_in, other.ret_in),
-                                     np.append(self.dark_in, other.dark_in),
-                                     np.append(self.delta_t, other.delta_t))
+        output = CalibrationSequence(
+            np.append(self.theta_pol_steps, other.theta_pol_steps) * 180 / np.pi,
+            np.append(self.theta_ret_steps, other.theta_ret_steps) * 180 / np.pi,
+            np.append(self.pol_in, other.pol_in),
+            np.append(self.ret_in, other.ret_in),
+            np.append(self.dark_in, other.dark_in),
+            np.append(self.delta_t, other.delta_t),
+        )
 
         output.t_pol_0 = np.append(self.t_pol_0, other.t_pol_0)
         output.t_ret_0 = np.append(self.t_ret_0, other.t_ret_0)
@@ -151,15 +174,23 @@ class CalibrationSequence():
         dresser : `Data.Dresser`
             Object containing one or more Drawers of SoCCs.
         """
-        for attr in ['theta_pol_steps', 'theta_ret_steps', 'pol_in', 'ret_in', 'dark_in', 'delta_t', 'numsteps']:
+        for attr in [
+            "theta_pol_steps",
+            "theta_ret_steps",
+            "pol_in",
+            "ret_in",
+            "dark_in",
+            "delta_t",
+            "numsteps",
+        ]:
             setattr(self, attr, getattr(dresser, attr))
 
-        self.py = 0.
-        self.Q_in = 0.
-        self.U_in = 0.
-        self.V_in = 0.
-        self.theta_pol_steps *= np.pi / 180
-        self.theta_ret_steps *= np.pi / 180
+        self.py = 0.0
+        self.Q_in = 0.0
+        self.U_in = 0.0
+        self.V_in = 0.0
+        self.theta_pol_steps = self.theta_pol_steps * np.pi / 180
+        self.theta_ret_steps = self.theta_ret_steps * np.pi / 180
         self.sequence_nums = dresser.drawer_step_list
         self.t_pol_0 = 1 + np.zeros(dresser.numdrawers, dtype=np.float64)
         self.t_ret_0 = 1 + np.zeros(dresser.numdrawers, dtype=np.float64)
@@ -169,7 +200,7 @@ class CalibrationSequence():
         self.dret_45 = np.zeros(dresser.numdrawers, dtype=np.float64)
         self.ret_0_r = np.zeros(dresser.numdrawers, dtype=np.float64)
         self.dret_r = np.zeros(dresser.numdrawers, dtype=np.float64)
-        self.I_sys = 1. + np.zeros(dresser.numdrawers, dtype=np.float64)
+        self.I_sys = 1.0 + np.zeros(dresser.numdrawers, dtype=np.float64)
 
     def load_pars_from_dict(self, params):
         """Update CU Model parameters based on a dictionary of the same
@@ -184,22 +215,22 @@ class CalibrationSequence():
         params : dict
             CU Model parameter key: value pairs
         """
-        self.Q_in = params['Q_in']
-        self.U_in = params['U_in']
-        self.V_in = params['V_in']
+        self.Q_in = params["Q_in"]
+        self.U_in = params["U_in"]
+        self.V_in = params["V_in"]
 
         for i in range(self.numdrawers):
-            self.t_pol_0[i] = params['t_pol_CS{:02n}'.format(i)]
-            self.t_ret_0[i] = params['t_ret_CS{:02n}'.format(i)]
+            self.t_pol_0[i] = params["t_pol_CS{:02n}".format(i)]
+            self.t_ret_0[i] = params["t_ret_CS{:02n}".format(i)]
 
-            self.I_sys[i] = params['I_sys_CS{:02n}'.format(i)]
+            self.I_sys[i] = params["I_sys_CS{:02n}".format(i)]
 
-            self.ret_0_h[i] = params['ret0h_CS{:02n}'.format(i)]
-            self.dret_h[i] = params['dreth_CS{:02n}'.format(i)]
-            self.ret_0_45[i] = params['ret045_CS{:02n}'.format(i)]
-            self.dret_45[i] = params['dret45_CS{:02n}'.format(i)]
-            self.ret_0_r[i] = params['ret0r_CS{:02n}'.format(i)]
-            self.dret_r[i] = params['dretr_CS{:02n}'.format(i)]
+            self.ret_0_h[i] = params["ret0h_CS{:02n}".format(i)]
+            self.dret_h[i] = params["dreth_CS{:02n}".format(i)]
+            self.ret_0_45[i] = params["ret045_CS{:02n}".format(i)]
+            self.dret_45[i] = params["dret45_CS{:02n}".format(i)]
+            self.ret_0_r[i] = params["ret0r_CS{:02n}".format(i)]
+            self.dret_r[i] = params["dretr_CS{:02n}".format(i)]
 
     def set_py_from_database(self, wavelength):
         """Update the transmission coefficient in the y direction (py)
@@ -207,10 +238,13 @@ class CalibrationSequence():
         Linear interpolation is used to match the input wavelength. py values outside of the database wavelength range
         are simply extended from the min/max database values.
         """
-        wave, py = np.loadtxt(pkg_resources.resource_filename('dkist_processing_pac', 'data/py_table.txt'), unpack=True)
+        wave, py = np.loadtxt(
+            pkg_resources.resource_filename("dkist_processing_pac", "data/py_table.txt"),
+            unpack=True,
+        )
         self.py = np.interp(wavelength, wave, py)
 
-        print('{}: py = {:7.6f} at {:4n} nm'.format(tag(), self.py, wavelength))
+        logging.info(f"py = {self.py:7.6f} at {wavelength:4n} nm")
 
     @property
     def t_pol(self):
@@ -276,7 +310,9 @@ class CalibrationSequence():
         for i in range(self.numdrawers):
             id2 += self.sequence_nums[i]
 
-            S_in[id1:id2] = self.I_sys[i] * np.array([[1., self.Q_in, self.U_in, self.V_in]] * self.sequence_nums[i])
+            S_in[id1:id2] = self.I_sys[i] * np.array(
+                [[1.0, self.Q_in, self.U_in, self.V_in]] * self.sequence_nums[i]
+            )
             id1 = id2
 
         return S_in
@@ -361,7 +397,9 @@ class CalibrationSequence():
 
         for i in range(self.numsteps):
             if self.pol_in[i]:
-                theta_pol = -self.theta_pol_steps[i] + np.pi / 2.  # Header/213 coordinate conversion
+                theta_pol = (
+                    -self.theta_pol_steps[i] + np.pi / 2.0
+                )  # Header/213 coordinate conversion
                 rot_in = Data.rotation(theta_pol)
                 rot_out = Data.rotation(-theta_pol)
 
@@ -391,7 +429,11 @@ class CalibrationSequence():
                 theta_ret = -self.theta_ret_steps[i]  # Header/213 coordinate conversion
                 rot_in = Data.rotation(theta_ret)
                 rot_out = Data.rotation(-theta_ret)
-                ret_mat[i] = rot_out @ Data.elliptical_retarder(t_ret[i], ret_h[i], ret_45[i], ret_r[i]) @ rot_in
+                ret_mat[i] = (
+                    rot_out
+                    @ Data.elliptical_retarder(t_ret[i], ret_h[i], ret_45[i], ret_r[i])
+                    @ rot_in
+                )
             else:
                 ret_mat[i] = np.diag(np.ones(4, dtype=np.float64))
 
@@ -402,7 +444,7 @@ class CalibrationSequence():
         dark_mat = np.empty((self.numsteps, 4, 4), dtype=np.float32)
         for i in range(self.numsteps):
             if self.dark_in[i]:
-                dark_mat[i] = np.zeros((4,4), dtype=np.float32)
+                dark_mat[i] = np.zeros((4, 4), dtype=np.float32)
             else:
                 dark_mat[i] = np.diag(np.ones(4, dtype=np.float32))
 
