@@ -1,12 +1,26 @@
+import logging
 import os
+
 import numpy as np
 from astropy.io import fits as pyfits
-from dkist_processing_pac import Data, CUModel, TelescopeModel, FittingFramework, generic
+
+from dkist_processing_pac import CUModel
+from dkist_processing_pac import Data
+from dkist_processing_pac import FittingFramework
+from dkist_processing_pac import generic
+from dkist_processing_pac import TelescopeModel
 from dkist_processing_pac.tag import tag
 
 
-def main(data_dir, CU_par_file, dmod_output, overwrite=True, suffix='.FITS', telescope_db='telescope_db.txt',
-         skip_darks=True):
+def main(
+    data_dir,
+    CU_par_file,
+    dmod_output,
+    overwrite=True,
+    suffix=".FITS",
+    telescope_db="telescope_db.txt",
+    skip_darks=True,
+):
     """Load previously-computed CU model parameters and use them to compute demodulation matrices.
 
     This function also requires a Drawer of PolCal data, which should be the exact same data used to fit the CU
@@ -44,114 +58,148 @@ def main(data_dir, CU_par_file, dmod_output, overwrite=True, suffix='.FITS', tel
 
     """
     if os.path.exists(dmod_output) and not overwrite:
-        raise IOError('File {} already exists and overwrite is False'.format(dmod_output))
+        raise IOError("File {} already exists and overwrite is False".format(dmod_output))
 
     DRWR = Data.Drawer(data_dir, suffix=suffix, skip_darks=skip_darks)
-    print('{}: loaded SoCC from {}'.format(tag(), data_dir))
+    print("{}: loaded SoCC from {}".format(tag(), data_dir))
 
     CMP = Data.CUModelParams(*(DRWR.shape + (1, DRWR.nummod)))
     CMP.loadfits(CU_par_file)
-    print('{}: loaded CU Model Parameters from {}'.format(tag(), CU_par_file))
+    print("{}: loaded CU Model Parameters from {}".format(tag(), CU_par_file))
 
     demodulation = core_demod(DRWR, CMP, telescope_db)
 
-    print('{}: saving demodulation matrices to {}'.format(tag(), dmod_output))
+    print("{}: saving demodulation matrices to {}".format(tag(), dmod_output))
     primary = pyfits.PrimaryHDU(header=DRWR.data_list[0][0].header)
-    primary.header['OBJECT'] = 'Demodulation matrix'
+    primary.header["OBJECT"] = "Demodulation matrix"
 
     dmod_hdu = pyfits.ImageHDU(demodulation, header=DRWR.data_list[0][0].header)
-    dmod_hdu.header['OBJECT'] = 'Demodulation matrix'
+    dmod_hdu.header["OBJECT"] = "Demodulation matrix"
     pyfits.HDUList([primary, dmod_hdu]).writeto(dmod_output, overwrite=overwrite)
     del DRWR
     CMP.cleanup()
 
     return
 
+
 def DC_main(dresser: Data.Dresser, cu_params: Data.CUModelParams, telescope_db: str) -> np.ndarray:
 
     if len(dresser.drawers) == 0:
-        raise ValueError('The provided dresser has no Drawers!')
+        raise ValueError("The provided dresser has no Drawers!")
     if len(dresser.drawers) > 1:
-        raise ValueError('The provided dresser has more than one Drawer')
+        raise ValueError("The provided dresser has more than one Drawer")
 
     drawer = dresser.drawers[0]
 
     return core_demod(drawer, cu_params, telescope_db)
 
+
 def core_demod(drawer: Data.Drawer, cu_params: Data.CUModelParams, telescope_db: str) -> np.ndarray:
 
-    mode_opts = generic.init_fit_mode(cu_params.fit_mode, drawer.wavelength, False, cu_params.init_set)
-    use_T = mode_opts['switches']['use_T']
-    use_M12 = mode_opts['switches']['use_M12']
+    mode_opts = generic.init_fit_mode(
+        cu_params.fit_mode, drawer.wavelength, False, cu_params.init_set
+    )
+    use_T = mode_opts["switches"]["use_T"]
+    use_M12 = mode_opts["switches"]["use_M12"]
 
-    CS = CUModel.CalibrationSequence(drawer.theta_pol_steps, drawer.theta_ret_steps, drawer.pol_in, drawer.ret_in,
-                                     drawer.dark_in, drawer.timeobs)
+    CS = CUModel.CalibrationSequence(
+        drawer.theta_pol_steps,
+        drawer.theta_ret_steps,
+        drawer.pol_in,
+        drawer.ret_in,
+        drawer.dark_in,
+        drawer.timeobs,
+    )
     TM = TelescopeModel.TelescopeModel(drawer.azimuth, drawer.elevation, drawer.table_angle)
 
-    print('{}: updating polarizer py value'.format(tag()))
+    logging.info("updating polarizer py value")
     wave = drawer.wavelength
     CS.set_py_from_database(wave)
 
-    print('{}: loading telescope database from {}'.format(tag(), telescope_db))
+    logging.info(f"loading telescope database from {telescope_db}")
     mean_time = 0.5 * (drawer.date_bgn + drawer.date_end)
     TM.load_from_database(telescope_db, mean_time, wave)
     numx, numy, numl = drawer.shape
     nummod = drawer.nummod
     demodulation = np.zeros((numx, numy, numl, 4, nummod), dtype=np.float64)
 
-    print('{}: shape of Drawer: ({}, {}, {})'.format(tag(), numx, numy, numl))
-    print('{}: computing demoduation matrices'.format(tag()))
+    logging.info(f"shape of Drawer: ({numx}, {numy}, {numl})")
+    logging.info("computing demoduation matrices")
     for i in range(numx):
         for j in range(numy):
             for k in range(numl):
-                print('{}:  position = ({}, {}, {})'.format(tag(), i, j, k))
+                logging.info(f"position = ({i}, {j}, {k})")
                 I_cal = drawer[i, j, k]
                 CS.load_pars_from_dict(cu_params[i, j, k])
 
-                print('{}:  fitting modulation matrix to best CU model'.format(tag()))
+                logging.info("  fitting modulation matrix to best CU model")
                 S = FittingFramework.generate_S(TM, CS, use_T=use_T, use_M12=use_M12)
                 try:
                     O = FittingFramework.fit_modulation_matrix(I_cal, S)
                 except ValueError as e:
-                    if 'illegal value' in str(e):
-                        print('{}:  Garbage results detected. Setting pass-through demodulation matrix.'.format(tag()))
+                    if "illegal value" in str(e):
+                        logging.info(
+                            "  Garbage results detected. Setting pass-through demodulation matrix."
+                        )
                         O = np.zeros((nummod, 4))
-                        O[:, 0] = 1./nummod
+                        O[:, 0] = 1.0 / nummod
                     else:
                         raise
 
-                print('{}:  computing inverse of modulation matrix'.format(tag()))
+                logging.info("  computing inverse of modulation matrix".format(tag()))
                 demodulation[i, j, k, :, :] = np.linalg.pinv(O)
 
     return demodulation
 
+
 def command_line():
     import argparse
     import sys
 
-    parser = argparse.ArgumentParser(description='Generate demodulation matrices from a single Calibration Sequence. '
-                                     'The data directory specified must contain a separate FITS file for each step in '
-                                     'the CS that has already been processed by the instrument reduction code. The '
-                                     'CU par file is the output of `pac_cu_par`.')
-    parser.add_argument('data_dir', help='Directory containing a single Calibration Sequence')
-    parser.add_argument('CU_pars', help='FITS file containing best fit Calibration Unit parameters')
-    parser.add_argument('output', help='Location of FITS file to save demodulation matrices')
-    parser.add_argument('-f', '--force', action='store_true', help='Overwrite outputs')
-    parser.add_argument('-t', '--telescope-db', help='Database listing telescope parameters as function of obstime and '
-                                                     'wavelength. This option is ignored if telescope_db is defined in '
-                                                     'a provided CONFIG_FILE (-c).', default=None)
-    parser.add_argument('-s', '--suffix', help='File suffix to filter data. File mask is data_dir/*suffix',
-                        default='.FITS')
-    parser.add_argument('-D', '--use-darks', action='store_false', help='Include any DARK CS steps in the fit')
+    parser = argparse.ArgumentParser(
+        description="Generate demodulation matrices from a single Calibration Sequence. "
+        "The data directory specified must contain a separate FITS file for each step in "
+        "the CS that has already been processed by the instrument reduction code. The "
+        "CU par file is the output of `pac_cu_par`."
+    )
+    parser.add_argument("data_dir", help="Directory containing a single Calibration Sequence")
+    parser.add_argument("CU_pars", help="FITS file containing best fit Calibration Unit parameters")
+    parser.add_argument("output", help="Location of FITS file to save demodulation matrices")
+    parser.add_argument("-f", "--force", action="store_true", help="Overwrite outputs")
+    parser.add_argument(
+        "-t",
+        "--telescope-db",
+        help="Database listing telescope parameters as function of obstime and "
+        "wavelength. This option is ignored if telescope_db is defined in "
+        "a provided CONFIG_FILE (-c).",
+        default=None,
+    )
+    parser.add_argument(
+        "-s",
+        "--suffix",
+        help="File suffix to filter data. File mask is data_dir/*suffix",
+        default=".FITS",
+    )
+    parser.add_argument(
+        "-D", "--use-darks", action="store_false", help="Include any DARK CS steps in the fit"
+    )
     args = parser.parse_args()
 
     if args.telescope_db is None:
         args.telescope_db = generic.get_default_telescope_db()
 
     if os.path.exists(args.data_dir):
-        sys.exit(main(args.data_dir, args.CU_pars, args.output, suffix=args.suffix, overwrite=args.force,
-                      telescope_db=args.telescope_db, skip_darks=args.use_darks))
+        sys.exit(
+            main(
+                args.data_dir,
+                args.CU_pars,
+                args.output,
+                suffix=args.suffix,
+                overwrite=args.force,
+                telescope_db=args.telescope_db,
+                skip_darks=args.use_darks,
+            )
+        )
     else:
-        print('Directory {} does not exist. Aborting.'.format(args.data_dir))
+        print("Directory {} does not exist. Aborting.".format(args.data_dir))
         sys.exit(1)
-
