@@ -1,19 +1,23 @@
+import logging
 import time
 import warnings
+
 import numpy as np
+import scipy.interpolate as spi
 from astropy.io import fits as pyfits
 from astropy.time import Time
-import scipy.interpolate as spi
 from scipy.spatial.qhull import QhullError
-from dkist_processing_pac import Data, generic
+
+from dkist_processing_pac import Data
+from dkist_processing_pac import generic
 from dkist_processing_pac.tag import tag
 
-warnings.simplefilter('always', UserWarning)
+warnings.simplefilter("always", UserWarning)
 ATOL = 1e-6
 RTOL = 1e-6
 
 
-class TelescopeModel():
+class TelescopeModel:
     """Build up the Mueller matrix of the full "Telescope Model" for use in PA&C analysis. As detailed in the DKIST
     PolCal Plan this model is parametrized by 3 mirror groups (M12, M34, M56) and the rotation matrices between them.
     The mirror Mueller matrices are calculated in real time from the parameters x (the ration of reflectivity between
@@ -56,8 +60,11 @@ class TelescopeModel():
         self.azimuth = np.atleast_1d(azimuth) * np.pi / 180
         self.table_angle = np.atleast_1d(table_angle) * np.pi / 180
 
-        if self.elevation.shape != self.azimuth.shape or self.elevation.shape != self.table_angle.shape:
-            raise ValueError('Telescope geometry vectors do not have the same shape')
+        if (
+            self.elevation.shape != self.azimuth.shape
+            or self.elevation.shape != self.table_angle.shape
+        ):
+            raise ValueError("Telescope geometry vectors do not have the same shape")
 
         self.numsteps = self.elevation.size
 
@@ -72,13 +79,15 @@ class TelescopeModel():
         TelescopeModel
             A new TelescopeModel object
         """
-        output = TelescopeModel(np.append(self.azimuth, other.azimuth) * 180 / np.pi,
-                                np.append(self.elevation, other.elevation) * 180 / np.pi,
-                                np.append(self.table_angle, other.table_angle) * 180 / np.pi)
+        output = TelescopeModel(
+            np.append(self.azimuth, other.azimuth) * 180 / np.pi,
+            np.append(self.elevation, other.elevation) * 180 / np.pi,
+            np.append(self.table_angle, other.table_angle) * 180 / np.pi,
+        )
 
         return output
 
-    def load_from_database(self, db_file, obstime, obswave, method='linear'):
+    def load_from_database(self, db_file, obstime, obswave, method="linear"):
         """Update (x, t) mirror parameters based on a database of previous measurements.
 
         Given a date and wavelength, the closest set of parameters is found via interpolation. The default is to use
@@ -109,38 +118,42 @@ class TelescopeModel():
 
         """
         times, wave, x12, t12, x34, t34, x56, t56 = np.loadtxt(db_file, unpack=True)
-        print(f"{tag()}: Loading database parameters from {db_file} for {obswave} at {Time(obstime, format='mjd').fits}")
+        logging.info(
+            f"Loading database parameters from {db_file} for {obswave} at {Time(obstime, format='mjd').fits}"
+        )
 
-        for source, target in zip([x12, t12, x34, t34, x56, t56],
-                                  ['x12', 't12', 'x34', 't34', 'x56', 't56']):
+        for source, target in zip(
+            [x12, t12, x34, t34, x56, t56], ["x12", "t12", "x34", "t34", "x56", "t56"]
+        ):
 
             try:
-                value = float(spi.griddata((times, wave), source, (obstime, obswave), method=method))
+                value = float(
+                    spi.griddata((times, wave), source, (obstime, obswave), method=method)
+                )
             except QhullError:
-                warnings.warn('Telescope database lacks diversity along either time or wavelength axis. '
-                              'Reverting to nearest neighbor interpolation.')
-                value = float(spi.griddata((times, wave), source, (obstime, obswave), method='nearest'))
-
+                value = float(
+                    spi.griddata((times, wave), source, (obstime, obswave), method="nearest")
+                )
 
             # griddata returns NaN if out of range
             if np.isnan(value):
                 warnings.warn(
-                        'Requested time/wavelength is outside of the Telescope Database range, using the nearest '
-                        'in-bounds value')
-                value = float(spi.griddata((times, wave), source, (obstime, obswave), method='nearest'))
+                    "Requested time/wavelength is outside of the Telescope Database range, using the nearest "
+                    "in-bounds value"
+                )
+                value = float(
+                    spi.griddata((times, wave), source, (obstime, obswave), method="nearest")
+                )
 
             setattr(self, target, value)
-            
+
         self.wavelength = obswave
         self.obstime = obstime
-        print('{:}: loaded (x12, t12, x34, t34, x56, t56) = ({:.5f}, {:.5f}, {:.5f}, {:.5f}, {:.5f}, {:.5f}) at {:} nm'.format(tag(),
-                                                                                                                               self.x12,
-                                                                                                                               self.t12,
-                                                                                                                               self.x34,
-                                                                                                                               self.t34,
-                                                                                                                               self.x56,
-                                                                                                                               self.t56,
-                                                                                                                               self.wavelength))
+        logging.info(
+            "loaded (x12, t12, x34, t34, x56, t56) = ({:.5f}, {:.5f}, {:.5f}, {:.5f}, {:.5f}, {:.5f}) at {:} nm".format(
+                self.x12, self.t12, self.x34, self.t34, self.x56, self.t56, self.wavelength
+            )
+        )
 
     def save_to_database(self, db_file, obstime=None, obswave=None):
         """Update the telescope database with the current class telescope mirror parameters.
@@ -158,11 +171,13 @@ class TelescopeModel():
         obswave : float
             The wavelength (nm) of the current observation.
         """
-        if obstime == 'now':
-            new_time = Time(time.time(), format='unix').mjd
+        if obstime == "now":
+            new_time = Time(time.time(), format="unix").mjd
         elif obstime is None:
             if self.obstime is None:
-                raise ValueError('Obstime was not set in the Telescope Model nor specified explicitly')
+                raise ValueError(
+                    "Obstime was not set in the Telescope Model nor specified explicitly"
+                )
             else:
                 new_time = self.obstime
         else:
@@ -170,21 +185,20 @@ class TelescopeModel():
 
         if obswave is None:
             if self.wavelength is None:
-                raise ValueError('Wavelength was not set in the Telescope Model nor specified explicitly')
+                raise ValueError(
+                    "Wavelength was not set in the Telescope Model nor specified explicitly"
+                )
             else:
                 new_wave = self.wavelength
         else:
             new_wave = obswave
 
-        with open(db_file, 'a') as f:
-            f.write(str('{:15.6f}' + '{:8.2f}' + '{:7.3f}' * 6 + '\n').format(new_time,
-                                                                              new_wave,
-                                                                              self.x12,
-                                                                              self.t12,
-                                                                              self.x34,
-                                                                              self.t34,
-                                                                              self.x56,
-                                                                              self.t56))
+        with open(db_file, "a") as f:
+            f.write(
+                str("{:15.6f}" + "{:8.2f}" + "{:7.3f}" * 6 + "\n").format(
+                    new_time, new_wave, self.x12, self.t12, self.x34, self.t34, self.x56, self.t56
+                )
+            )
 
     def save_FITS(self, outputfile, overwrite=False):
         """Save a FITS file with the M3 - M7 Mueller matrix and M12 Muller matrix as separate HDUs.
@@ -195,24 +209,24 @@ class TelescopeModel():
         """
 
         if self.numsteps > 1:
-            warnings.warn('Multiple telescope geometries found. Only using the first configuration')
+            warnings.warn("Multiple telescope geometries found. Only using the first configuration")
 
         primary = pyfits.PrimaryHDU()
-        primary.header['TAZIMUTH'] = self.azimuth[0]
-        primary.header['TELEVATN'] = self.elevation[0]
-        primary.header['TTBLANGL'] = self.table_angle[0]
-        primary.header['X12'] = self.x12
-        primary.header['T12'] = self.t12
-        primary.header['X34'] = self.x34
-        primary.header['T34'] = self.t34
-        primary.header['X56'] = self.x56
-        primary.header['T56'] = self.t56
+        primary.header["TAZIMUTH"] = self.azimuth[0]
+        primary.header["TELEVATN"] = self.elevation[0]
+        primary.header["TTBLANGL"] = self.table_angle[0]
+        primary.header["X12"] = self.x12
+        primary.header["T12"] = self.t12
+        primary.header["X34"] = self.x34
+        primary.header["T34"] = self.t34
+        primary.header["X56"] = self.x56
+        primary.header["T56"] = self.t56
 
         tm = pyfits.ImageHDU(self.TM[0, :, :])
-        tm.header['NAME'] = ('TM', 'Mueller matrix for mirrors 3-6')
+        tm.header["NAME"] = ("TM", "Mueller matrix for mirrors 3-6")
 
         m12 = pyfits.ImageHDU(self.M12)
-        m12.header['NAME'] = ('M12', 'Mueller matrix for M12 group')
+        m12.header["NAME"] = ("M12", "Mueller matrix for M12 group")
 
         pyfits.HDUList([primary, tm, m12]).writeto(outputfile, overwrite=overwrite)
 
@@ -244,16 +258,18 @@ class TelescopeModel():
             full_model = full_model @ self.M12
 
         if full_model.shape[0] > 1:
-            warnings.warn('Multiple telescope geometries found. Only using the first configuration')
+            warnings.warn("Multiple telescope geometries found. Only using the first configuration")
 
         inverse = np.linalg.inv(full_model[0, :, :])
 
-        if not (np.allclose(np.diag(np.ones(4)), inverse @ full_model[0], rtol=RTOL, atol=ATOL) and
-                np.allclose(np.diag(np.ones(4)), full_model[0] @ inverse, rtol=RTOL, atol=ATOL)):
-            raise ArithmeticError('The generated inverse is not mathematically valid')
+        if not (
+            np.allclose(np.diag(np.ones(4)), inverse @ full_model[0], rtol=RTOL, atol=ATOL)
+            and np.allclose(np.diag(np.ones(4)), full_model[0] @ inverse, rtol=RTOL, atol=ATOL)
+        ):
+            raise ArithmeticError("The generated inverse is not mathematically valid")
 
         if include_parallactic:
-            time = Time(self.obstime, format='mjd')
+            time = Time(self.obstime, format="mjd")
             p_rot = Data.rotation(-1 * generic.compute_parallactic_angle(time))
             inverse = p_rot @ inverse
 
@@ -283,7 +299,7 @@ class TelescopeModel():
         numpy.ndarray
             Array of shape (4, 4)
         """
-        return Data.rotation(-np.pi / 2.)
+        return Data.rotation(-np.pi / 2.0)
 
     @property
     def R45(self):
